<?php
/**
 * Content wrappers
 *
 * @author 		Vamtam
 * @package 	wpv
 * @subpackage  construction
 * @version     3.3.0
 */

global $post;

?>
		</div>
	</article>
	<?php VamtamTemplates::right_sidebar() ?>
</div>
